@@ -37,17 +37,10 @@ const (
 	DisplayDefault Property = "display_default"
 )
 
-type properties struct {
-	values     map[Property]interface{}
-	foreground string
-	background string
-}
+type properties map[Property]interface{}
 
-func (p *properties) getString(property Property, defaultValue string) string {
-	if p == nil || p.values == nil {
-		return defaultValue
-	}
-	val, found := p.values[property]
+func (p properties) getString(property Property, defaultValue string) string {
+	val, found := p[property]
 	if !found {
 		return defaultValue
 	}
@@ -62,31 +55,24 @@ func parseString(value interface{}, defaultValue string) string {
 	return stringValue
 }
 
-func (p *properties) getColor(property Property, defaultValue string) string {
-	if p == nil || p.values == nil {
-		return defaultValue
-	}
-	val, found := p.values[property]
+func (p properties) getColor(property Property, defaultValue string) string {
+	val, found := p[property]
 	if !found {
 		return defaultValue
 	}
 	colorString := parseString(val, defaultValue)
-	_, err := getColorFromName(colorString, false)
-	if err == nil {
+	if IsAnsiColorName(colorString) {
 		return colorString
 	}
-	values := findNamedRegexMatch(`(?P<color>#[A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})`, colorString)
+	values := findNamedRegexMatch(`(?P<color>#[A-Fa-f0-9]{6}|[A-Fa-f0-9]{3}|p:.*)`, colorString)
 	if values != nil && values["color"] != "" {
 		return values["color"]
 	}
 	return defaultValue
 }
 
-func (p *properties) getBool(property Property, defaultValue bool) bool {
-	if p == nil || p.values == nil {
-		return defaultValue
-	}
-	val, found := p.values[property]
+func (p properties) getBool(property Property, defaultValue bool) bool {
+	val, found := p[property]
 	if !found {
 		return defaultValue
 	}
@@ -97,11 +83,8 @@ func (p *properties) getBool(property Property, defaultValue bool) bool {
 	return boolValue
 }
 
-func (p *properties) getFloat64(property Property, defaultValue float64) float64 {
-	if p == nil || p.values == nil {
-		return defaultValue
-	}
-	val, found := p.values[property]
+func (p properties) getFloat64(property Property, defaultValue float64) float64 {
+	val, found := p[property]
 	if !found {
 		return defaultValue
 	}
@@ -114,11 +97,8 @@ func (p *properties) getFloat64(property Property, defaultValue float64) float64
 	return floatValue
 }
 
-func (p *properties) getInt(property Property, defaultValue int) int {
-	if p == nil || p.values == nil {
-		return defaultValue
-	}
-	val, found := p.values[property]
+func (p properties) getInt(property Property, defaultValue int) int {
+	val, found := p[property]
 	if !found {
 		return defaultValue
 	}
@@ -136,11 +116,8 @@ func (p *properties) getInt(property Property, defaultValue int) int {
 	return int(intValue)
 }
 
-func (p *properties) getKeyValueMap(property Property, defaultValue map[string]string) map[string]string {
-	if p == nil || p.values == nil {
-		return defaultValue
-	}
-	val, found := p.values[property]
+func (p properties) getKeyValueMap(property Property, defaultValue map[string]string) map[string]string {
+	val, found := p[property]
 	if !found {
 		return defaultValue
 	}
@@ -150,6 +127,17 @@ func (p *properties) getKeyValueMap(property Property, defaultValue map[string]s
 	return keyValues
 }
 
+func (p properties) getStringArray(property Property, defaultValue []string) []string {
+	val, found := p[property]
+	if !found {
+		return defaultValue
+	}
+
+	keyValues := parseStringArray(val)
+
+	return keyValues
+}
+
 func parseStringArray(param interface{}) []string {
 	switch v := param.(type) {
 	default:
