@@ -1,7 +1,7 @@
 package main
 
 type text struct {
-	props   *properties
+	props   properties
 	env     environmentInfo
 	content string
 }
@@ -26,7 +26,7 @@ func (t *text) string() string {
 	return t.content
 }
 
-func (t *text) init(props *properties, env environmentInfo) {
+func (t *text) init(props properties, env environmentInfo) {
 	t.props = props
 	t.env = env
 }
